# Always prefer setuptools over distutils
from setuptools import setup, find_packages

# To use a consistent encoding
from codecs import open
from os import path

# The directory containing this file
HERE = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(HERE, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

    # This call to setup() does all the work
    setup(
        name="geometry-543",
        version="0.1.1",
        description="Demo library",
        long_description=long_description,
        long_description_content_type="text/markdown",
        url="https://medium-multiply.readthedocs.io/",
        author="Andre Larsson",
        author_email="example@email.com",
        license="MIT",
        classifiers=[
            "Intended Audience :: Developers",
            "License :: OSI Approved :: MIT License",
            "Programming Language :: Python",
            "Programming Language :: Python :: 3",
            "Programming Language :: Python :: 3.7",
            "Programming Language :: Python :: 3.8",
            "Programming Language :: Python :: 3.9",
            "Operating System :: OS Independent"
        ],
        packages=["geometry_543"],
        include_package_data=True,
        install_requires=["numpy"]
    )



import numpy as np

class Ellipse:
    """
    Instantiate a representation of an ellipse.

    :param r0: length of first axis
    :type number: float

    :param r1: length of second axis
    :type number: float
    """

    
    def __init__(self, r0, r1):
        self.r0 = r0
        self.r1 = r1

        
    def calc_area(self):
        """
        Calculate the area of this ellipse
        """
        return self.r0*self.r1*np.pi
    
